@@ -14,7 +14,6 @@
 import dataclasses
 
 import dataclasses_json
-
 from card_framework import AutoNumber, enum_field, standard_field
 
 
@@ -24,23 +23,23 @@ class ActionStatus(object):
   """ActionStatus
   """
   class Code(AutoNumber):
-    OK = 'OK'
-    CANCELLED = 'CANCELLED'
-    UNKNOWN = 'UNKNOWN'
-    INVALID_ARGUMENT = 'INVALID_ARGUMENT'
-    DEADLINE_EXCEEDED = 'DEADLINE_EXCEEDED'
-    NOT_FOUND = 'NOT_FOUND'
-    ALREADY_EXISTS = 'ALREADY_EXISTS'
-    PERMISSION_DENIED = 'PERMISSION_DENIED'
-    UNAUTHENTICATED = 'UNAUTHENTICATED'
-    RESOURCE_EXHAUSTED = 'RESOURCE_EXHAUSTED'
-    FAILED_PRECONDITION = 'FAILED_PRECONDITION'
-    ABORTED = 'ABORTED'
-    OUT_OF_RANGE = 'OUT_OF_RANGE'
-    UNIMPLEMENTED = 'UNIMPLEMENTED'
-    INTERNAL = 'INTERNAL'
-    UNAVAILABLE = 'UNAVAILABLE'
-    DATA_LOSS = 'DATA_LOSS'
+    OK = ()
+    CANCELLED = ()
+    UNKNOWN = ()
+    INVALID_ARGUMENT = ()
+    DEADLINE_EXCEEDED = ()
+    NOT_FOUND = ()
+    ALREADY_EXISTS = ()
+    PERMISSION_DENIED = ()
+    UNAUTHENTICATED = ()
+    RESOURCE_EXHAUSTED = ()
+    FAILED_PRECONDITION = ()
+    ABORTED = ()
+    OUT_OF_RANGE = ()
+    UNIMPLEMENTED = ()
+    INTERNAL = ()
+    UNAVAILABLE = ()
+    DATA_LOSS = ()
 
   status_code: Code = enum_field()
   user_facing_message: str = standard_field()
