@@ -25,11 +25,11 @@ from .user import User
 
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass
-class Annotation(object):
+class Annotation(card_framework.Renderable):
   class AnnotationType(card_framework.AutoNumber):
-    ANNOTATION_TYPE_UNSPECIFIED = 'ANNOTATION_TYPE_UNSPECIFIED'
-    USER_MENTION = 'USER_MENTION'
-    SLASH_COMMAND = 'SLASH_COMMAND'
+    ANNOTATION_TYPE_UNSPECIFIED = ()
+    USER_MENTION = ()
+    SLASH_COMMAND = ()
 
   type: AnnotationType = card_framework.enum_field()
   startIndex: int = card_framework.standard_field()
@@ -55,9 +55,9 @@ class Annotation(object):
         _type_: _description_
     """
     if __value:
-      if __name == 'user_mention':
+      if __name == ():
         self.slash_command = None
-      elif __name == 'slash_command':
+      elif __name == ():
         self.user_mention = None
 
     super().__setattr__(__name, __value)
@@ -79,58 +79,34 @@ class Annotation(object):
     """
     if all([self.slash_command, self.user_mention]):
       raise ValueError('Only one of [slash_command, user_mention] can be set.')
-    elif not(any([self.slash_command, self.user_mention])):
+    elif not (any([self.slash_command, self.user_mention])):
       raise ValueError(f'One of [slash_command, user_mention] must be set.')
 
     return super().to_dict(encode_json)
 
-  def render(self) -> Mapping[str, Any]:
-    """Renders the response to json.
-
-    Returns:
-        Mapping[str, Any]: _description_
-    """
-    return {'annotation': self.to_dict(), }
-
 
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass
 class UserMentionMetadata(object):
   class UserMentionMetadataType(card_framework.AutoNumber):
-    TYPE_UNSPECIFIED = 'TYPE_UNSPECIFIED'
-    ADD = 'ADD'
-    MENTION = 'MENTION'
+    TYPE_UNSPECIFIED = ()
+    ADD = ()
+    MENTION = ()
 
   user: User = card_framework.standard_field()
   type: UserMentionMetadataType = card_framework.enum_field()
 
-  def render(self) -> Mapping[str, Any]:
-    """Renders the response to json.
-
-    Returns:
-        Mapping[str, Any]: _description_
-    """
-    return self.to_dict()
-
 
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass
 class SlashCommandMetadata(object):
   class SlashCommandMetadataType(card_framework.AutoNumber):
-    TYPE_UNSPECIFIED = 'TYPE_UNSPECIFIED'
-    ADD = 'ADD'
-    INVOKE = 'INVOKE'
+    TYPE_UNSPECIFIED = ()
+    ADD = ()
+    INVOKE = ()
 
   bot: User = card_framework.standard_field()
   type: SlashCommandMetadataType = card_framework.enum_field()
   command_name: str = card_framework.standard_field()
   command_id: str = card_framework.standard_field()
   triggers_dialog: bool = card_framework.standard_field()
-
-  def render(self) -> Mapping[str, Any]:
-    """Renders the response to json.
-
-    Returns:
-        Mapping[str, Any]: _description_
-    """
-    return self.to_dict()
