@@ -31,34 +31,34 @@ class Icon(DataClassJsonMixin):
 
     https://developers.google.com/chat/api/guides/message-formats/cards#builtinicons
     """
-    AIRPLANE = 'AIRPLANE'
-    BOOKMARK = 'BOOKMARK'
-    BUS = 'BUS'
-    CAR = 'CAR'
-    CLOCK = 'CLOCK'
-    CONFIRMATION_NUMBER_ICON = 'CONFIRMATION_NUMBER_ICON'
-    DESCRIPTION = 'DESCRIPTION'
-    DOLLAR = 'DOLLAR'
-    EMAIL = 'EMAIL'
-    EVENT_SEAT = 'EVENT_SEAT'
-    FLIGHT_ARRIVAL = 'FLIGHT_ARRIVAL'
-    FLIGHT_DEPARTURE = 'FLIGHT_DEPARTURE'
-    HOTEL = 'HOTEL'
-    HOTEL_ROOM_TYPE = 'HOTEL_ROOM_TYPE'
-    INVITE = 'INVITE'
-    MAP_PIN = 'MAP_PIN'
-    MEMBERSHIP = 'MEMBERSHIP'
-    MULTIPLE_PEOPLE = 'MULTIPLE_PEOPLE'
-    PERSON = 'PERSON'
-    PHONE = 'PHONE'
-    RESTAURANT_ICON = 'RESTAURANT_ICON'
-    SHOPPING_CART = 'SHOPPING_CART'
-    STAR = 'STAR'
-    STORE = 'STORE'
-    TICKET = 'TICKET'
-    TRAIN = 'TRAIN'
-    VIDEO_CAMERA = 'VIDEO_CAMERA'
-    VIDEO_PLAY = 'VIDEO_PLAY'
+    AIRPLANE = ()
+    BOOKMARK = ()
+    BUS = ()
+    CAR = ()
+    CLOCK = ()
+    CONFIRMATION_NUMBER_ICON = ()
+    DESCRIPTION = ()
+    DOLLAR = ()
+    EMAIL = ()
+    EVENT_SEAT = ()
+    FLIGHT_ARRIVAL = ()
+    FLIGHT_DEPARTURE = ()
+    HOTEL = ()
+    HOTEL_ROOM_TYPE = ()
+    INVITE = ()
+    MAP_PIN = ()
+    MEMBERSHIP = ()
+    MULTIPLE_PEOPLE = ()
+    PERSON = ()
+    PHONE = ()
+    RESTAURANT_ICON = ()
+    SHOPPING_CART = ()
+    STAR = ()
+    STORE = ()
+    TICKET = ()
+    TRAIN = ()
+    VIDEO_CAMERA = ()
+    VIDEO_PLAY = ()
 
   alt_text: Optional[str] = standard_field()
   icon_url: Optional[str] = standard_field()
